@@ -1,11 +1,11 @@
 findipl <-
-function(XX,FF,j)
+function(x,y,j)
 {
-  n=dim(XX)[1]
-  x1=XX[1]
-  y1=FF[1]
-  x2=XX[j]
-  y2=FF[j]
+  n=dim(x)[1]
+  x1=x[1]
+  y1=y[1]
+  x2=x[j]
+  y2=y[j]
   flin1=function(x)
   {
     lin2(x1,y1,x2,y2,x)
@@ -13,12 +13,12 @@ function(XX,FF,j)
   sl=0
   for (i in 1:(j-1))
   {
-    sl=sl+eixf(XX,FF,flin1,i)
+    sl=sl+eixf(x,y,flin1,i)
   }
-  x1=XX[j]
-  y1=FF[j]
-  x2=XX[n]
-  y2=FF[n]
+  x1=x[j]
+  y1=y[j]
+  x2=x[n]
+  y2=y[n]
   flin2=function(x)
   {
     lin2(x1,y1,x2,y2,x)
@@ -26,7 +26,7 @@ function(XX,FF,j)
   sr=0
   for (k in j:(n-1))
   {
-    sr=sr+eixf(XX,FF,flin2,k)
-  }
-  c(j,XX[j],sl,sr)
+    sr=sr+eixf(x,y,flin2,k)
   }
+  c(j,x[j],sl,sr)
+}
